package server;

import java.rmi.RemoteException;
import java.util.Collection;
import java.util.ArrayList;
import java.util.Iterator;
import javax.naming.*;
import javax.ejb.CreateException;
import javax.ejb.EJBException;
import javax.ejb.SessionBean;
import javax.ejb.SessionContext;

/**
 * @author knk
 *
 * JVelox - www.jvelox.com.br
 */
public class CourseManagerBean implements SessionBean {
	
	transient private Context ctx;
	
	protected SessionContext sessionContext;

	/**
	 * Constructor for CourseManagerBean.
	 */
	public CourseManagerBean() {
		super();
	}
	
	private Context getContext() {
		try {
			if (ctx == null) {
				ctx = new InitialContext();
			}
			return ctx;
		} catch (NamingException ex) {
			throw new EJBException(ex);
		}
	}

	/**
	 * @see SessionBean#setSessionContext(SessionContext)
	 */
	public void setSessionContext(SessionContext sessionContext) {
		this.sessionContext = sessionContext;
	}

	/**
	 * @see SessionBean#ejbRemove()
	 */
	public void ejbRemove() {
	}

	/**
	 * @see SessionBean#ejbActivate()
	 */
	public void ejbActivate() {
	}

	/**
	 * @see SessionBean#ejbPassivate()
	 */
	public void ejbPassivate() {
	}
	
	public void ejbCreate() throws CreateException {
	}
	
	public void createCourse(String name) {
		try {
			CourseHome home = (CourseHome)this.getContext().lookup("local/Course");
			home.create(name);
		} catch (Exception ex) {
			throw new EJBException(ex);
		}
	}
	
	public void createTeacher(String name) {
		try {
			TeacherHome home = (TeacherHome)this.getContext().lookup("local/Teacher");
			home.create(name);
		} catch (Exception ex) {
			throw new EJBException(ex);
		}
	}
	
	public void createStudent(String name) {
		try {
			StudentHome home = (StudentHome)this.getContext().lookup("local/Student");
			home.create(name);
		} catch (Exception ex) {
			throw new EJBException(ex);
		}
	}
	
	public Collection getStudentsCourses(StudentPk pk) {
		try {
			StudentHome stdHome = (StudentHome)this.getContext().lookup("local/Student");
			Student student = stdHome.findByPrimaryKey(pk);
			Collection coursesNames = new ArrayList();
			for (Iterator iter = student.getCourses().iterator(); iter.hasNext();) {
				coursesNames.add( ((Course)iter.next()).getName() );
				
			}
			return coursesNames;
		} catch (Exception ex) {
			throw new EJBException(ex);
		}
	}
	
	public Collection getTeacherCourses(TeacherPk pk) {
		try {
			TeacherHome teachhome = (TeacherHome)this.getContext().lookup("local/Teacher");
			Teacher teacher = teachhome.findByPrimaryKey(pk);
			Collection coursesNames = new ArrayList();
			for (Iterator iter = teacher.getCourses().iterator(); iter.hasNext();) {
				coursesNames.add( ((Course)iter.next()).getName() );
				
			}
			return coursesNames;
		} catch (Exception ex) {
			throw new EJBException(ex);
		}
	}
	
	public void bindStudentCourse(StudentPk stdPk, CoursePk coursePk) {
		try {
			StudentHome stdHome = (StudentHome)this.getContext().lookup("local/Student");
			CourseHome courseHome = (CourseHome)this.getContext().lookup("local/Course");			
			Student student = stdHome.findByPrimaryKey(stdPk);
			Course course = courseHome.findByPrimaryKey(coursePk);
			student.getCourses().add(course);
		} catch (Exception ex) {
			throw new EJBException(ex);
		}		
	}
	
	public void bindTeacherCourse(TeacherPk teachPk, CoursePk coursePk) {
		try {		
			TeacherHome teachhome = (TeacherHome)this.getContext().lookup("local/Teacher");
			CourseHome courseHome = (CourseHome)this.getContext().lookup("local/Course");			
			Teacher teacher = teachhome.findByPrimaryKey(teachPk);
			Course course = courseHome.findByPrimaryKey(coursePk);
			teacher.getCourses().add(course);
		} catch (Exception ex) {
			throw new EJBException(ex);
		}		
		
	}
	

}
